@@ -1,5 +1,6 @@
 # coding: utf-8
 
+import codecs
 import copy
 import imp
 import inspect
@@ -63,7 +64,7 @@ def get_schema_specs(schema_id, swagger):
                 return swag
 
 
-def get_specs(rules, ignore_verbs, optional_fields, sanitizer):
+def get_specs(rules, ignore_verbs, optional_fields, sanitizer, doc_dir=None):
 
     specs = []
     for rule in rules:
@@ -88,11 +89,11 @@ def get_specs(rules, ignore_verbs, optional_fields, sanitizer):
 
             klass = method.__dict__.get('view_class', None)
             if not is_mv and klass and hasattr(klass, 'verb'):
-                method = klass.__dict__.get('verb')
+                method = getattr(klass, 'verb', None)
             elif klass and hasattr(klass, 'dispatch_request'):
-                method = klass.__dict__.get('dispatch_request')
+                method = getattr(klass, 'dispatch_request', None)
             if method is None:  # for MethodView
-                method = klass.__dict__.get(verb)
+                method = getattr(klass, verb, None)
 
             if method is None:
                 if is_mv:  # #76 Empty MethodViews
@@ -128,6 +129,19 @@ def get_specs(rules, ignore_verbs, optional_fields, sanitizer):
 
                 swagged = True
 
+            if doc_dir:
+                if view_class:
+                    file_path = os.path.join(
+                        doc_dir, endpoint.__name__, method.__name__ + '.yml')
+                else:
+                    file_path = os.path.join(
+                        doc_dir, endpoint.__name__ + '.yml')
+                if os.path.isfile(file_path):
+                    func = method.__func__ \
+                        if hasattr(method, '__func__') else method
+                    setattr(func, 'swag_type', 'yml')
+                    setattr(func, 'swag_path', file_path)
+
             doc_summary, doc_description, doc_swag = parse_docstring(
                 method, sanitizer, endpoint=rule.endpoint, verb=verb)
 
@@ -451,7 +465,8 @@ def load_from_file(swag_path, swag_type='yml', root_path=None):
         # TODO: support JSON
 
     try:
-        with open(swag_path) as yaml_file:
+        enc = detect_by_bom(swag_path)
+        with codecs.open(swag_path, encoding=enc) as yaml_file:
             return yaml_file.read()
     except IOError:
         # not in the same dir, add dirname
@@ -459,7 +474,8 @@ def load_from_file(swag_path, swag_type='yml', root_path=None):
             root_path or os.path.dirname(__file__), swag_path
         )
         try:
-            with open(swag_path) as yaml_file:
+            enc = detect_by_bom(swag_path)
+            with codecs.open(swag_path, encoding=enc) as yaml_file:
                 return yaml_file.read()
         except IOError:  # pragma: no cover
             # if package dir
@@ -477,6 +493,18 @@ def load_from_file(swag_path, swag_type='yml', root_path=None):
                 return yaml_file.read()
 
 
+def detect_by_bom(path, default='utf-8'):
+    with open(path, 'rb') as f:
+        raw = f.read(4)  # will read less if the file is smaller
+    for enc, boms in \
+            ('utf-8-sig', (codecs.BOM_UTF8,)),\
+            ('utf-16', (codecs.BOM_UTF16_LE, codecs.BOM_UTF16_BE)),\
+            ('utf-32', (codecs.BOM_UTF32_LE, codecs.BOM_UTF32_BE)):
+        if any(raw.startswith(bom) for bom in boms):
+            return enc
+    return default
+
+
 def parse_docstring(obj, process_doc, endpoint=None, verb=None):
     """
     Gets swag data for method/view docstring
